==> knative-model-6.8.0-sources.jar: io/fabric8/knative/internal/pkg/apis/duck/v1alpha1/AddressableFluent.java <==
package io.fabric8.knative.internal.pkg.apis.duck.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class AddressableFluent<A extends AddressableFluent<A>> extends BaseFluent<A>{
  public AddressableFluent() {
  }
  public AddressableFluent(Addressable instance) {
    instance = (instance != null ? instance : new Addressable());

    if (instance != null) {
      this.withCACerts(instance.getCACerts());
      this.withHostname(instance.getHostname());
      this.withName(instance.getName());
      this.withUrl(instance.getUrl());
      this.withCACerts(instance.getCACerts());
      this.withHostname(instance.getHostname());
      this.withName(instance.getName());
      this.withUrl(instance.getUrl());
    }
  }
  private String cACerts;
  private String hostname;
  private String name;
  private String url;
  public String getCACerts() {
    return this.cACerts;
  }
  public A withCACerts(String cACerts) {
    this.cACerts=cACerts; return (A) this;
  }
  public boolean hasCACerts() {
    return this.cACerts != null;
  }
  public String getHostname() {
    return this.hostname;
  }
  public A withHostname(String hostname) {
    this.hostname=hostname; return (A) this;
  }
  public boolean hasHostname() {
    return this.hostname != null;
  }
  public String getName() {
    return this.name;
  }
  public A withName(String name) {
    this.name=name; return (A) this;
  }
  public boolean hasName() {
    return this.name != null;
  }
  public String getUrl() {
    return this.url;
  }
  public A withUrl(String url) {
    this.url=url; return (A) this;
  }
  public boolean hasUrl() {
    return this.url != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    AddressableFluent that = (AddressableFluent) o;
    if (!java.util.Objects.equals(cACerts, that.cACerts)) return false;

    if (!java.util.Objects.equals(hostname, that.hostname)) return false;

    if (!java.util.Objects.equals(name, that.name)) return false;

    if (!java.util.Objects.equals(url, that.url)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(cACerts,  hostname,  name,  url,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (cACerts != null) { sb.append("cACerts:"); sb.append(cACerts + ","); }
    if (hostname != null) { sb.append("hostname:"); sb.append(hostname + ","); }
    if (name != null) { sb.append("name:"); sb.append(name + ","); }
    if (url != null) { sb.append("url:"); sb.append(url); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> knative-model-6.9.0-sources.jar: io/fabric8/knative/internal/pkg/apis/duck/v1alpha1/AddressableFluent.java <==
package io.fabric8.knative.internal.pkg.apis.duck.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class AddressableFluent<A extends AddressableFluent<A>> extends BaseFluent<A>{
  public AddressableFluent() {
  }
  
  public AddressableFluent(Addressable instance) {
    this.copyInstance(instance);
  }
  private String cACerts;
  private String hostname;
  private String name;
  private String url;
  
  protected void copyInstance(Addressable instance) {
    instance = (instance != null ? instance : new Addressable());
  
    if (instance != null) {
        this.withCACerts(instance.getCACerts());
        this.withHostname(instance.getHostname());
        this.withName(instance.getName());
        this.withUrl(instance.getUrl());
        this.withCACerts(instance.getCACerts());
        this.withHostname(instance.getHostname());
        this.withName(instance.getName());
        this.withUrl(instance.getUrl());
      }
  }
  
  public String getCACerts() {
    return this.cACerts;
  }
  
  public A withCACerts(String cACerts) {
    this.cACerts=cACerts; return (A) this;
  }
  
  public boolean hasCACerts() {
    return this.cACerts != null;
  }
  
  public String getHostname() {
    return this.hostname;
  }
  
  public A withHostname(String hostname) {
    this.hostname=hostname; return (A) this;
  }
  
  public boolean hasHostname() {
    return this.hostname != null;
  }
  
  public String getName() {
    return this.name;
  }
  
  public A withName(String name) {
    this.name=name; return (A) this;
  }
  
  public boolean hasName() {
    return this.name != null;
  }
  
  public String getUrl() {
    return this.url;
  }
  
  public A withUrl(String url) {
    this.url=url; return (A) this;
  }
  
  public boolean hasUrl() {
    return this.url != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    AddressableFluent that = (AddressableFluent) o;
    if (!java.util.Objects.equals(cACerts, that.cACerts)) return false;
  
    if (!java.util.Objects.equals(hostname, that.hostname)) return false;
  
    if (!java.util.Objects.equals(name, that.name)) return false;
  
    if (!java.util.Objects.equals(url, that.url)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(cACerts,  hostname,  name,  url,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (cACerts != null) { sb.append("cACerts:"); sb.append(cACerts + ","); }
    if (hostname != null) { sb.append("hostname:"); sb.append(hostname + ","); }
    if (name != null) { sb.append("name:"); sb.append(name + ","); }
    if (url != null) { sb.append("url:"); sb.append(url); }
    sb.append("}");
    return sb.toString();
  }
  

}
